translate.misc.ini.INIConfig

Package translate :: Package misc :: Module ini :: Class INIConfig |
[hide private]
[frames] | no frames]

# Class INIConfig

source code

Instance Methods | [hide private]
__init__(self, fp=None, defaults=None, parse_exc=True, optionxformvalue=<method 'lower' of 'str' objects>, optionxformsource=None, sectionxformvalue=None, sectionxformsource=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
__getitem__(self, key) | source code
__setitem__(self, key, value) | source code
__delitem__(self, key) | source code
__iter__(self) | source code
new_namespace(self, name) | source code
__str__(self) str(x) | source code
_parse(self, line) | source code
readfp(self, fp) | source code
Inherited from `iniparse.config.ConfigNamespace`: `__delattr__`, `__getattr__`, `__getstate__`, `__setattr__`, `__setstate__` Inherited from `iniparse.config.ConfigNamespace` (private): `_new_namespace` Inherited from `object`: `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
| _data = `None` hash(x)
| _sections = `None` hash(x)
| _defaults = `None` hash(x)
| _optionxformvalue = `None` hash(x)
| _optionxformsource = `None` hash(x)
| _sectionxformvalue = `None` hash(x)
| _sectionxformsource = `None` hash(x)
| _parse_exc = `None` hash(x)
| _line_types = ``[`<class 'translate.misc.ini.EmptyLine'>`,` <class `...``

Properties | [hide private]
| _optionxform
| _sectionxform
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, fp=None, defaults=None, parse_exc=True, optionxformvalue=<method 'lower' of 'str' objects>, optionxformsource=None, sectionxformvalue=None, sectionxformsource=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __getitem__(self, key) (Indexing operator) | source code
Overrides: iniparse.config.ConfigNamespace.__getitem__

### __setitem__(self, key, value) (Index assignment operator) | source code
Overrides: iniparse.config.ConfigNamespace.__setitem__

### __delitem__(self, key) (Index deletion operator) | source code
Overrides: iniparse.config.ConfigNamespace.__delitem__

### __iter__(self) | source code
Overrides: iniparse.config.ConfigNamespace.__iter__

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)

Class Variable Details | [hide private]

  ### _line_types Value:
      [<class 'translate.misc.ini.EmptyLine'>,
       <class 'translate.misc.ini.CommentLine'>,
       <class 'translate.misc.ini.SectionLine'>,
       <class 'translate.misc.ini.OptionLine'>,
       <class 'translate.misc.ini.ContinuationLine'>]

Property Details | [hide private]

### _optionxform Get Method: unreachable.getfn(self) Set Method: unreachable.setfn(self, value)

### _sectionxform Get Method: unreachable.getfn(self) Set Method: unreachable.setfn(self, value)